# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_match_management.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2
import dota2.protobufs.dota_client_enums_pb2 as dota__client__enums__pb2
import dota2.protobufs.base_gcmessages_pb2 as base__gcmessages__pb2
import dota2.protobufs.dota_gcmessages_common_match_management_pb2 as dota__gcmessages__common__match__management__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_match_management.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n-dota_gcmessages_client_match_management.proto\x1a\x13steammessages.proto\x1a\x17\x64ota_shared_enums.proto\x1a\x17\x64ota_client_enums.proto\x1a\x15\x62\x61se_gcmessages.proto\x1a-dota_gcmessages_common_match_management.proto\"\xe4\x03\n\x15\x43MsgStartFindingMatch\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x0bmatchgroups\x18\x02 \x01(\r:\n4294967295\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12\x1e\n\ngame_modes\x18\x04 \x01(\r:\n4294967295\x12?\n\x0e\x62ot_difficulty\x18\x05 \x01(\x0e\x32\x12.DOTABotDifficulty:\x13\x42OT_DIFFICULTY_HARD\x12\x31\n\nmatch_type\x18\x06 \x01(\x0e\x32\n.MatchType:\x11MATCH_TYPE_CASUAL\x12\"\n\x0ematchlanguages\x18\x07 \x01(\r:\n4294967295\x12\x16\n\x0emap_preference\x18\t \x01(\r\x12\x0f\n\x07team_id\x18\x08 \x01(\r\x12\x43\n\x12game_language_enum\x18\n \x01(\x0e\x32\x0f.MatchLanguages:\x16MATCH_LANGUAGE_INVALID\x12\x1a\n\x12game_language_name\x18\x0b \x01(\t\x12&\n\tping_data\x18\x0c \x01(\x0b\x32\x13.CMsgClientPingData\x12\x1b\n\x13region_select_flags\x18\r \x01(\r\"\xde\x01\n\x1b\x43MsgStartFindingMatchResult\x12!\n\x16legacy_generic_eresult\x18\x01 \x01(\r:\x01\x32\x12M\n\x06result\x18\x02 \x01(\x0e\x32\x19.EStartFindingMatchResult:\"k_EStartFindingMatchResult_Invalid\x12\x13\n\x0b\x65rror_token\x18\x03 \x01(\t\x12\x15\n\rdebug_message\x18\x04 \x01(\t\x12!\n\x19responsible_party_members\x18\x05 \x03(\x06\"\x16\n\x14\x43MsgStopFindingMatch\"\xce\x01\n\x17\x43MsgPartyBuilderOptions\x12\x18\n\x10\x61\x64\x64itional_slots\x18\x01 \x01(\r\x12\x31\n\nmatch_type\x18\x02 \x01(\x0e\x32\n.MatchType:\x11MATCH_TYPE_CASUAL\x12\x13\n\x0bmatchgroups\x18\x03 \x01(\r\x12\x16\n\x0e\x63lient_version\x18\x04 \x01(\r\x12\x39\n\x08language\x18\x05 \x01(\x0e\x32\x0f.MatchLanguages:\x16MATCH_LANGUAGE_INVALID\"\x9b\x01\n\x0b\x43MsgReadyUp\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32\x14.DOTALobbyReadyState:\x1e\x44OTALobbyReadyState_UNDECLARED\x12\x14\n\x0cready_up_key\x18\x02 \x01(\x06\x12\x31\n\x0ehardware_specs\x18\x03 \x01(\x0b\x32\x19.CDOTAClientHardwareSpecs\"Q\n\x11\x43MsgReadyUpStatus\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x61\x63\x63\x65pted_ids\x18\x02 \x03(\r\x12\x14\n\x0c\x64\x65\x63lined_ids\x18\x03 \x03(\r\"\x18\n\x16\x43MsgAbandonCurrentGame\"\xea\x0b\n\x1b\x43MsgPracticeLobbySetDetails\x12\x10\n\x08lobby_id\x18\x01 \x01(\x04\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12(\n\x0cteam_details\x18\x03 \x03(\x0b\x32\x12.CLobbyTeamDetails\x12\x15\n\rserver_region\x18\x04 \x01(\r\x12\x11\n\tgame_mode\x18\x05 \x01(\r\x12.\n\x07\x63m_pick\x18\x06 \x01(\x0e\x32\r.DOTA_CM_PICK:\x0e\x44OTA_CM_RANDOM\x12J\n\x16\x62ot_difficulty_radiant\x18\t \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\x12\x14\n\x0c\x61llow_cheats\x18\n \x01(\x08\x12\x16\n\x0e\x66ill_with_bots\x18\x0b \x01(\x08\x12\x12\n\nintro_mode\x18\x0c \x01(\x08\x12\x18\n\x10\x61llow_spectating\x18\r \x01(\x08\x12<\n\x0cgame_version\x18\x0e \x01(\x0e\x32\x10.DOTAGameVersion:\x14GAME_VERSION_CURRENT\x12\x10\n\x08pass_key\x18\x0f \x01(\t\x12\x10\n\x08leagueid\x18\x10 \x01(\r\x12\x1d\n\x15penalty_level_radiant\x18\x11 \x01(\r\x12\x1a\n\x12penalty_level_dire\x18\x12 \x01(\r\x12\x14\n\x0cload_game_id\x18\x13 \x01(\r\x12\x13\n\x0bseries_type\x18\x14 \x01(\r\x12\x1b\n\x13radiant_series_wins\x18\x15 \x01(\r\x12\x18\n\x10\x64ire_series_wins\x18\x16 \x01(\r\x12\x16\n\x07\x61llchat\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x39\n\rdota_tv_delay\x18\x18 \x01(\x0e\x32\x11.LobbyDotaTVDelay:\x0fLobbyDotaTV_120\x12\x0b\n\x03lan\x18\x19 \x01(\x08\x12\x18\n\x10\x63ustom_game_mode\x18\x1a \x01(\t\x12\x17\n\x0f\x63ustom_map_name\x18\x1b \x01(\t\x12\x19\n\x11\x63ustom_difficulty\x18\x1c \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x1d \x01(\x04\x12\x1a\n\x12\x63ustom_min_players\x18\x1e \x01(\r\x12\x1a\n\x12\x63ustom_max_players\x18\x1f \x01(\r\x12&\n\x1elan_host_ping_to_server_region\x18  \x01(\r\x12\x44\n\nvisibility\x18! \x01(\x0e\x32\x14.DOTALobbyVisibility:\x1a\x44OTALobbyVisibility_Public\x12\x17\n\x0f\x63ustom_game_crc\x18\" \x01(\x06\x12\x18\n\x10league_series_id\x18# \x01(\r\x12\x16\n\x0eleague_game_id\x18$ \x01(\r\x12\x1d\n\x15\x63ustom_game_timestamp\x18% \x01(\x07\x12\x1f\n\x17previous_match_override\x18& \x01(\x04\x12&\n\x1eleague_selection_priority_team\x18\' \x01(\r\x12K\n league_selection_priority_choice\x18( \x01(\x0e\x32\x16.SelectionPriorityType:\tUNDEFINED\x12O\n$league_non_selection_priority_choice\x18) \x01(\x0e\x32\x16.SelectionPriorityType:\tUNDEFINED\x12N\n\rpause_setting\x18* \x01(\x0e\x32\x16.LobbyDotaPauseSetting:\x1fLobbyDotaPauseSetting_Unlimited\x12G\n\x13\x62ot_difficulty_dire\x18+ \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\x12\x13\n\x0b\x62ot_radiant\x18, \x01(\x04\x12\x10\n\x08\x62ot_dire\x18- \x01(\x04\"\x92\x02\n\x17\x43MsgPracticeLobbyCreate\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x10\n\x08pass_key\x18\x05 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x06 \x01(\r\x12\x33\n\rlobby_details\x18\x07 \x01(\x0b\x32\x1c.CMsgPracticeLobbySetDetails\x12\x34\n\tsave_game\x18\x08 \x01(\x0b\x32!.CMsgPracticeLobbyCreate.SaveGame\x1aN\n\x08SaveGame\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x10\n\x08steam_id\x18\x03 \x01(\x06\x12\x11\n\tsignature\x18\x04 \x01(\x06\"\xa5\x01\n\x1c\x43MsgPracticeLobbySetTeamSlot\x12\x33\n\x04team\x18\x01 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\x12\x0c\n\x04slot\x18\x02 \x01(\r\x12\x42\n\x0e\x62ot_difficulty\x18\x03 \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\"P\n\x19\x43MsgPracticeLobbySetCoach\x12\x33\n\x04team\x18\x01 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\"\x98\x01\n%CMsgPracticeLobbyJoinBroadcastChannel\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\x1d\n\x15preferred_description\x18\x02 \x01(\t\x12\x1e\n\x16preferred_country_code\x18\x03 \x01(\t\x12\x1f\n\x17preferred_language_code\x18\x04 \x01(\t\"9\n&CMsgPracticeLobbyCloseBroadcastChannel\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\"8\n6CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus\"+\n\x15\x43MsgPracticeLobbyKick\x12\x12\n\naccount_id\x18\x03 \x01(\r\"3\n\x1d\x43MsgPracticeLobbyKickFromTeam\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\x18\n\x16\x43MsgPracticeLobbyLeave\"1\n\x17\x43MsgPracticeLobbyLaunch\x12\x16\n\x0e\x63lient_version\x18\x05 \x01(\r\"/\n\x1c\x43MsgApplyTeamToPracticeLobby\x12\x0f\n\x07team_id\x18\x01 \x01(\r\"\x1c\n\x1a\x43MsgClearPracticeLobbyTeam\"\x8a\x01\n\x15\x43MsgPracticeLobbyList\x12\x18\n\x10tournament_games\x18\x01 \x01(\x08\x12\x10\n\x08pass_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\r\x12\x35\n\tgame_mode\x18\x04 \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\"\xce\x04\n\"CMsgPracticeLobbyListResponseEntry\x12\x10\n\x02id\x18\x01 \x01(\x04\x42\x04\x80\x97\"\x01\x12\x15\n\rtournament_id\x18\x03 \x01(\r\x12\x1a\n\x12tournament_game_id\x18\x04 \x01(\r\x12\x41\n\x07members\x18\x05 \x03(\x0b\x32\x30.CMsgPracticeLobbyListResponseEntry.CLobbyMember\x12\x19\n\x11requires_pass_key\x18\x06 \x01(\x08\x12\x19\n\x11leader_account_id\x18\x07 \x01(\r\x12\x10\n\x08guild_id\x18\x08 \x01(\r\x12\x12\n\nguild_logo\x18\t \x01(\x04\x12\x0c\n\x04name\x18\n \x01(\t\x12\x18\n\x10\x63ustom_game_mode\x18\x0b \x01(\t\x12\x35\n\tgame_mode\x18\x0c \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\x12\x16\n\x0e\x66riend_present\x18\r \x01(\x08\x12\x0f\n\x07players\x18\x0e \x01(\r\x12\x17\n\x0f\x63ustom_map_name\x18\x0f \x01(\t\x12\x18\n\x10max_player_count\x18\x10 \x01(\r\x12\x15\n\rserver_region\x18\x11 \x01(\r\x12&\n\x1elan_host_ping_to_server_region\x18\x12 \x01(\r\x12\x11\n\tleague_id\x18\x13 \x01(\r\x1a\x37\n\x0c\x43LobbyMember\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\"o\n\x1d\x43MsgPracticeLobbyListResponse\x12\x18\n\x10tournament_games\x18\x01 \x01(\x08\x12\x34\n\x07lobbies\x18\x02 \x03(\x0b\x32#.CMsgPracticeLobbyListResponseEntry\"`\n\rCMsgLobbyList\x12\x18\n\rserver_region\x18\x01 \x01(\r:\x01\x30\x12\x35\n\tgame_mode\x18\x02 \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\"M\n\x15\x43MsgLobbyListResponse\x12\x34\n\x07lobbies\x18\x01 \x03(\x0b\x32#.CMsgPracticeLobbyListResponseEntry\"\x8b\x01\n\x15\x43MsgPracticeLobbyJoin\x12\x10\n\x08lobby_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x10\n\x08pass_key\x18\x03 \x01(\t\x12\x17\n\x0f\x63ustom_game_crc\x18\x04 \x01(\x06\x12\x1d\n\x15\x63ustom_game_timestamp\x18\x05 \x01(\x07\"_\n\x1d\x43MsgPracticeLobbyJoinResponse\x12>\n\x06result\x18\x01 \x01(\x0e\x32\x14.DOTAJoinLobbyResult:\x18\x44OTA_JOIN_RESULT_SUCCESS\"5\n\"CMsgFriendPracticeLobbyListRequest\x12\x0f\n\x07\x66riends\x18\x01 \x03(\r\"[\n#CMsgFriendPracticeLobbyListResponse\x12\x34\n\x07lobbies\x18\x01 \x03(\x0b\x32#.CMsgPracticeLobbyListResponseEntry\"7\n%CMsgGuildmatePracticeLobbyListRequest\x12\x0e\n\x06guilds\x18\x01 \x03(\r\"^\n&CMsgGuildmatePracticeLobbyListResponse\x12\x34\n\x07lobbies\x18\x01 \x03(\x0b\x32#.CMsgPracticeLobbyListResponseEntry\";\n\"CMsgJoinableCustomGameModesRequest\x12\x15\n\rserver_region\x18\x01 \x01(\r\"m\n(CMsgJoinableCustomGameModesResponseEntry\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x13\n\x0blobby_count\x18\x02 \x01(\r\x12\x14\n\x0cplayer_count\x18\x03 \x01(\r\"d\n#CMsgJoinableCustomGameModesResponse\x12=\n\ngame_modes\x18\x01 \x03(\x0b\x32).CMsgJoinableCustomGameModesResponseEntry\"Q\n CMsgJoinableCustomLobbiesRequest\x12\x15\n\rserver_region\x18\x01 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x02 \x01(\x04\"\xb4\x02\n&CMsgJoinableCustomLobbiesResponseEntry\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63ustom_game_id\x18\x02 \x01(\x04\x12\x12\n\nlobby_name\x18\x03 \x01(\t\x12\x14\n\x0cmember_count\x18\x04 \x01(\r\x12\x19\n\x11leader_account_id\x18\x05 \x01(\r\x12\x13\n\x0bleader_name\x18\x06 \x01(\t\x12\x17\n\x0f\x63ustom_map_name\x18\x07 \x01(\t\x12\x18\n\x10max_player_count\x18\x08 \x01(\r\x12\x15\n\rserver_region\x18\t \x01(\r\x12&\n\x1elan_host_ping_to_server_region\x18\n \x01(\r\x12\x14\n\x0chas_pass_key\x18\x0b \x01(\x08\"]\n!CMsgJoinableCustomLobbiesResponse\x12\x38\n\x07lobbies\x18\x01 \x03(\x0b\x32\'.CMsgJoinableCustomLobbiesResponseEntry\"\xfa\x02\n\x18\x43MsgQuickJoinCustomLobby\x12\x1c\n\x14legacy_server_region\x18\x01 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x02 \x01(\x04\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12:\n\x14\x63reate_lobby_details\x18\x04 \x01(\x0b\x32\x1c.CMsgPracticeLobbySetDetails\x12\x15\n\rallow_any_map\x18\x05 \x01(\x08\x12G\n\x13legacy_region_pings\x18\x06 \x03(\x0b\x32*.CMsgQuickJoinCustomLobby.LegacyRegionPing\x12&\n\tping_data\x18\x07 \x01(\x0b\x32\x13.CMsgClientPingData\x1aL\n\x10LegacyRegionPing\x12\x15\n\rserver_region\x18\x01 \x01(\r\x12\x0c\n\x04ping\x18\x02 \x01(\r\x12\x13\n\x0bregion_code\x18\x03 \x01(\x07\"b\n CMsgQuickJoinCustomLobbyResponse\x12>\n\x06result\x18\x01 \x01(\x0e\x32\x14.DOTAJoinLobbyResult:\x18\x44OTA_JOIN_RESULT_SUCCESS\"\x94\x02\n\x11\x43MsgBotGameCreate\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x46\n\x12\x64ifficulty_radiant\x18\x03 \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\x12\x33\n\x04team\x18\x04 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\x12\x11\n\tgame_mode\x18\x05 \x01(\r\x12\x43\n\x0f\x64ifficulty_dire\x18\x06 \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\"\x8e\x01\n\x14\x43MsgCustomGameCreate\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x12\n\ndifficulty\x18\x03 \x01(\r\x12\x11\n\tgame_mode\x18\x04 \x01(\t\x12\x0b\n\x03map\x18\x05 \x01(\t\x12\x16\n\x0e\x63ustom_game_id\x18\x07 \x01(\x04\"\x8d\x01\n\x13\x43MsgEventGameCreate\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x12\n\ndifficulty\x18\x03 \x01(\r\x12\x11\n\tgame_mode\x18\x04 \x01(\t\x12\x0b\n\x03map\x18\x05 \x01(\t\x12\x16\n\x0e\x63ustom_game_id\x18\x07 \x01(\x04\"2\n\x1b\x43MsgDOTAPartyMemberSetCoach\x12\x13\n\x0bwants_coach\x18\x01 \x01(\x08\"4\n\x16\x43MsgDOTASetGroupLeader\x12\x1a\n\x12new_leader_steamid\x18\x01 \x01(\x06\"P\n\x1a\x43MsgDOTACancelGroupInvites\x12\x18\n\x10invited_steamids\x18\x01 \x03(\x06\x12\x18\n\x10invited_groupids\x18\x02 \x03(\x06\"*\n\x1a\x43MsgDOTASetGroupOpenStatus\x12\x0c\n\x04open\x18\x01 \x01(\x08\"2\n\x18\x43MsgDOTAGroupMergeInvite\x12\x16\n\x0eother_group_id\x18\x01 \x01(\x06\"H\n\x1a\x43MsgDOTAGroupMergeResponse\x12\x1a\n\x12initiator_group_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"]\n\x17\x43MsgDOTAGroupMergeReply\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x16.EDOTAGroupMergeResult:\x1ak_EDOTAGroupMergeResult_OK\"\xf4\x02\n\x1d\x43MsgSpectatorLobbyGameDetails\x12\x10\n\x08language\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x17\n\x0fserver_steam_id\x18\x03 \x01(\x06\x12\x12\n\nstream_url\x18\x04 \x01(\t\x12\x13\n\x0bstream_name\x18\x05 \x01(\t\x12\x11\n\tleague_id\x18\x06 \x01(\r\x12\x13\n\x0bseries_type\x18\x07 \x01(\r\x12\x13\n\x0bseries_game\x18\x08 \x01(\r\x12\x39\n\x0cradiant_team\x18\t \x01(\x0b\x32#.CMsgSpectatorLobbyGameDetails.Team\x12\x36\n\tdire_team\x18\n \x01(\x0b\x32#.CMsgSpectatorLobbyGameDetails.Team\x1a=\n\x04Team\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x11\n\tteam_name\x18\x02 \x01(\t\x12\x11\n\tteam_logo\x18\x03 \x01(\x06\"\x8c\x01\n\x1c\x43MsgSetSpectatorLobbyDetails\x12\x10\n\x08lobby_id\x18\x01 \x01(\x04\x12\x12\n\nlobby_name\x18\x02 \x01(\t\x12\x10\n\x08pass_key\x18\x03 \x01(\t\x12\x34\n\x0cgame_details\x18\x04 \x01(\x0b\x32\x1e.CMsgSpectatorLobbyGameDetails\"b\n\x18\x43MsgCreateSpectatorLobby\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\x12.\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x1d.CMsgSetSpectatorLobbyDetails\"\x18\n\x16\x43MsgSpectatorLobbyList\"\x9b\x02\n\x1e\x43MsgSpectatorLobbyListResponse\x12?\n\x07lobbies\x18\x01 \x03(\x0b\x32..CMsgSpectatorLobbyListResponse.SpectatorLobby\x1a\xb7\x01\n\x0eSpectatorLobby\x12\x10\n\x08lobby_id\x18\x01 \x01(\x04\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12\x19\n\x11requires_pass_key\x18\x03 \x01(\x08\x12\x19\n\x11leader_account_id\x18\x04 \x01(\r\x12\x14\n\x0cmember_count\x18\x05 \x01(\r\x12\x34\n\x0cgame_details\x18\x07 \x01(\x0b\x32\x1e.CMsgSpectatorLobbyGameDetails\"C\n(CMsgClientToGCRequestSteamDatagramTicket\x12\x17\n\x0fserver_steam_id\x18\x01 \x01(\x06\"^\n0CMsgClientToGCRequestSteamDatagramTicketResponse\x12\x19\n\x11serialized_ticket\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t*\xac\n\n\x18\x45StartFindingMatchResult\x12&\n\"k_EStartFindingMatchResult_Invalid\x10\x00\x12!\n\x1dk_EStartFindingMatchResult_OK\x10\x01\x12/\n+k_EStartFindingMatchResult_AlreadySearching\x10\x02\x12*\n&k_EStartFindingMatchResult_FailGeneric\x10\x64\x12+\n\'k_EStartFindingMatchResult_FailedIgnore\x10\x65\x12\x32\n.k_EStartFindingMatchResult_MatchmakingDisabled\x10\x66\x12,\n(k_EStartFindingMatchResult_RegionOffline\x10g\x12\x32\n.k_EStartFindingMatchResult_MatchmakingCooldown\x10h\x12.\n*k_EStartFindingMatchResult_ClientOutOfDate\x10i\x12\x37\n3k_EStartFindingMatchResult_CompetitiveNoLowPriority\x10j\x12\x35\n1k_EStartFindingMatchResult_CompetitiveNotUnlocked\x10k\x12\x32\n.k_EStartFindingMatchResult_GameModeNotUnlocked\x10l\x12<\n8k_EStartFindingMatchResult_CompetitiveNotEnoughSkillData\x10m\x12\x32\n.k_EStartFindingMatchResult_MissingInitialSkill\x10n\x12<\n8k_EStartFindingMatchResult_CompetitiveRankSpreadTooLarge\x10o\x12\x33\n/k_EStartFindingMatchResult_MemberAlreadyInLobby\x10p\x12\x33\n/k_EStartFindingMatchResult_MemberNotVACVerified\x10q\x12\x39\n5k_EStartFindingMatchResult_WeekendTourneyBadPartySize\x10r\x12>\n:k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooSmall\x10s\x12\x44\n@k_EStartFindingMatchResult_WeekendTourneyIndividualBuyInTooLarge\x10t\x12>\n:k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooLarge\x10u\x12:\n6k_EStartFindingMatchResult_MemberMissingEventOwnership\x10v\x12\x38\n4k_EStartFindingMatchResult_WeekendTourneyNotUnlocked\x10w\x12@\n<k_EStartFindingMatchResult_WeekendTourneyRecentParticipation\x10xB\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,dota__shared__enums__pb2.DESCRIPTOR,dota__client__enums__pb2.DESCRIPTOR,base__gcmessages__pb2.DESCRIPTOR,dota__gcmessages__common__match__management__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ESTARTFINDINGMATCHRESULT = _descriptor.EnumDescriptor(
  name='EStartFindingMatchResult',
  full_name='EStartFindingMatchResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_Invalid', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_OK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_AlreadySearching', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_FailGeneric', index=3, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_FailedIgnore', index=4, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MatchmakingDisabled', index=5, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_RegionOffline', index=6, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MatchmakingCooldown', index=7, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_ClientOutOfDate', index=8, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_CompetitiveNoLowPriority', index=9, number=106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_CompetitiveNotUnlocked', index=10, number=107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_GameModeNotUnlocked', index=11, number=108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_CompetitiveNotEnoughSkillData', index=12, number=109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MissingInitialSkill', index=13, number=110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_CompetitiveRankSpreadTooLarge', index=14, number=111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MemberAlreadyInLobby', index=15, number=112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MemberNotVACVerified', index=16, number=113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyBadPartySize', index=17, number=114,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooSmall', index=18, number=115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyIndividualBuyInTooLarge', index=19, number=116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooLarge', index=20, number=117,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_MemberMissingEventOwnership', index=21, number=118,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyNotUnlocked', index=22, number=119,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EStartFindingMatchResult_WeekendTourneyRecentParticipation', index=23, number=120,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8897,
  serialized_end=10221,
)
_sym_db.RegisterEnumDescriptor(_ESTARTFINDINGMATCHRESULT)

EStartFindingMatchResult = enum_type_wrapper.EnumTypeWrapper(_ESTARTFINDINGMATCHRESULT)
k_EStartFindingMatchResult_Invalid = 0
k_EStartFindingMatchResult_OK = 1
k_EStartFindingMatchResult_AlreadySearching = 2
k_EStartFindingMatchResult_FailGeneric = 100
k_EStartFindingMatchResult_FailedIgnore = 101
k_EStartFindingMatchResult_MatchmakingDisabled = 102
k_EStartFindingMatchResult_RegionOffline = 103
k_EStartFindingMatchResult_MatchmakingCooldown = 104
k_EStartFindingMatchResult_ClientOutOfDate = 105
k_EStartFindingMatchResult_CompetitiveNoLowPriority = 106
k_EStartFindingMatchResult_CompetitiveNotUnlocked = 107
k_EStartFindingMatchResult_GameModeNotUnlocked = 108
k_EStartFindingMatchResult_CompetitiveNotEnoughSkillData = 109
k_EStartFindingMatchResult_MissingInitialSkill = 110
k_EStartFindingMatchResult_CompetitiveRankSpreadTooLarge = 111
k_EStartFindingMatchResult_MemberAlreadyInLobby = 112
k_EStartFindingMatchResult_MemberNotVACVerified = 113
k_EStartFindingMatchResult_WeekendTourneyBadPartySize = 114
k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooSmall = 115
k_EStartFindingMatchResult_WeekendTourneyIndividualBuyInTooLarge = 116
k_EStartFindingMatchResult_WeekendTourneyTeamBuyInTooLarge = 117
k_EStartFindingMatchResult_MemberMissingEventOwnership = 118
k_EStartFindingMatchResult_WeekendTourneyNotUnlocked = 119
k_EStartFindingMatchResult_WeekendTourneyRecentParticipation = 120



_CMSGSTARTFINDINGMATCH = _descriptor.Descriptor(
  name='CMsgStartFindingMatch',
  full_name='CMsgStartFindingMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CMsgStartFindingMatch.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchgroups', full_name='CMsgStartFindingMatch.matchgroups', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgStartFindingMatch.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_modes', full_name='CMsgStartFindingMatch.game_modes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty', full_name='CMsgStartFindingMatch.bot_difficulty', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='CMsgStartFindingMatch.match_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchlanguages', full_name='CMsgStartFindingMatch.matchlanguages', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_preference', full_name='CMsgStartFindingMatch.map_preference', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgStartFindingMatch.team_id', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_language_enum', full_name='CMsgStartFindingMatch.game_language_enum', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_language_name', full_name='CMsgStartFindingMatch.game_language_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='CMsgStartFindingMatch.ping_data', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_select_flags', full_name='CMsgStartFindingMatch.region_select_flags', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=675,
)


_CMSGSTARTFINDINGMATCHRESULT = _descriptor.Descriptor(
  name='CMsgStartFindingMatchResult',
  full_name='CMsgStartFindingMatchResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_generic_eresult', full_name='CMsgStartFindingMatchResult.legacy_generic_eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgStartFindingMatchResult.result', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_token', full_name='CMsgStartFindingMatchResult.error_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='CMsgStartFindingMatchResult.debug_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responsible_party_members', full_name='CMsgStartFindingMatchResult.responsible_party_members', index=4,
      number=5, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=900,
)


_CMSGSTOPFINDINGMATCH = _descriptor.Descriptor(
  name='CMsgStopFindingMatch',
  full_name='CMsgStopFindingMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=924,
)


_CMSGPARTYBUILDEROPTIONS = _descriptor.Descriptor(
  name='CMsgPartyBuilderOptions',
  full_name='CMsgPartyBuilderOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_slots', full_name='CMsgPartyBuilderOptions.additional_slots', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='CMsgPartyBuilderOptions.match_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchgroups', full_name='CMsgPartyBuilderOptions.matchgroups', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPartyBuilderOptions.client_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgPartyBuilderOptions.language', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1133,
)


_CMSGREADYUP = _descriptor.Descriptor(
  name='CMsgReadyUp',
  full_name='CMsgReadyUp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgReadyUp.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ready_up_key', full_name='CMsgReadyUp.ready_up_key', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware_specs', full_name='CMsgReadyUp.hardware_specs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1291,
)


_CMSGREADYUPSTATUS = _descriptor.Descriptor(
  name='CMsgReadyUpStatus',
  full_name='CMsgReadyUpStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgReadyUpStatus.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accepted_ids', full_name='CMsgReadyUpStatus.accepted_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='declined_ids', full_name='CMsgReadyUpStatus.declined_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1374,
)


_CMSGABANDONCURRENTGAME = _descriptor.Descriptor(
  name='CMsgAbandonCurrentGame',
  full_name='CMsgAbandonCurrentGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1400,
)


_CMSGPRACTICELOBBYSETDETAILS = _descriptor.Descriptor(
  name='CMsgPracticeLobbySetDetails',
  full_name='CMsgPracticeLobbySetDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgPracticeLobbySetDetails.lobby_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CMsgPracticeLobbySetDetails.game_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_details', full_name='CMsgPracticeLobbySetDetails.team_details', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgPracticeLobbySetDetails.server_region', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgPracticeLobbySetDetails.game_mode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_pick', full_name='CMsgPracticeLobbySetDetails.cm_pick', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty_radiant', full_name='CMsgPracticeLobbySetDetails.bot_difficulty_radiant', index=6,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_cheats', full_name='CMsgPracticeLobbySetDetails.allow_cheats', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fill_with_bots', full_name='CMsgPracticeLobbySetDetails.fill_with_bots', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intro_mode', full_name='CMsgPracticeLobbySetDetails.intro_mode', index=9,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_spectating', full_name='CMsgPracticeLobbySetDetails.allow_spectating', index=10,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_version', full_name='CMsgPracticeLobbySetDetails.game_version', index=11,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CMsgPracticeLobbySetDetails.pass_key', index=12,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgPracticeLobbySetDetails.leagueid', index=13,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_level_radiant', full_name='CMsgPracticeLobbySetDetails.penalty_level_radiant', index=14,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_level_dire', full_name='CMsgPracticeLobbySetDetails.penalty_level_dire', index=15,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_game_id', full_name='CMsgPracticeLobbySetDetails.load_game_id', index=16,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgPracticeLobbySetDetails.series_type', index=17,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_series_wins', full_name='CMsgPracticeLobbySetDetails.radiant_series_wins', index=18,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_series_wins', full_name='CMsgPracticeLobbySetDetails.dire_series_wins', index=19,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allchat', full_name='CMsgPracticeLobbySetDetails.allchat', index=20,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dota_tv_delay', full_name='CMsgPracticeLobbySetDetails.dota_tv_delay', index=21,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan', full_name='CMsgPracticeLobbySetDetails.lan', index=22,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_mode', full_name='CMsgPracticeLobbySetDetails.custom_game_mode', index=23,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_map_name', full_name='CMsgPracticeLobbySetDetails.custom_map_name', index=24,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_difficulty', full_name='CMsgPracticeLobbySetDetails.custom_difficulty', index=25,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgPracticeLobbySetDetails.custom_game_id', index=26,
      number=29, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_min_players', full_name='CMsgPracticeLobbySetDetails.custom_min_players', index=27,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_max_players', full_name='CMsgPracticeLobbySetDetails.custom_max_players', index=28,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan_host_ping_to_server_region', full_name='CMsgPracticeLobbySetDetails.lan_host_ping_to_server_region', index=29,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='CMsgPracticeLobbySetDetails.visibility', index=30,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='CMsgPracticeLobbySetDetails.custom_game_crc', index=31,
      number=34, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_series_id', full_name='CMsgPracticeLobbySetDetails.league_series_id', index=32,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_game_id', full_name='CMsgPracticeLobbySetDetails.league_game_id', index=33,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='CMsgPracticeLobbySetDetails.custom_game_timestamp', index=34,
      number=37, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_match_override', full_name='CMsgPracticeLobbySetDetails.previous_match_override', index=35,
      number=38, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_selection_priority_team', full_name='CMsgPracticeLobbySetDetails.league_selection_priority_team', index=36,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_selection_priority_choice', full_name='CMsgPracticeLobbySetDetails.league_selection_priority_choice', index=37,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_non_selection_priority_choice', full_name='CMsgPracticeLobbySetDetails.league_non_selection_priority_choice', index=38,
      number=41, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pause_setting', full_name='CMsgPracticeLobbySetDetails.pause_setting', index=39,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty_dire', full_name='CMsgPracticeLobbySetDetails.bot_difficulty_dire', index=40,
      number=43, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_radiant', full_name='CMsgPracticeLobbySetDetails.bot_radiant', index=41,
      number=44, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_dire', full_name='CMsgPracticeLobbySetDetails.bot_dire', index=42,
      number=45, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1403,
  serialized_end=2917,
)


_CMSGPRACTICELOBBYCREATE_SAVEGAME = _descriptor.Descriptor(
  name='SaveGame',
  full_name='CMsgPracticeLobbyCreate.SaveGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgPracticeLobbyCreate.SaveGame.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgPracticeLobbyCreate.SaveGame.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgPracticeLobbyCreate.SaveGame.steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='CMsgPracticeLobbyCreate.SaveGame.signature', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3116,
  serialized_end=3194,
)

_CMSGPRACTICELOBBYCREATE = _descriptor.Descriptor(
  name='CMsgPracticeLobbyCreate',
  full_name='CMsgPracticeLobbyCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgPracticeLobbyCreate.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CMsgPracticeLobbyCreate.pass_key', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPracticeLobbyCreate.client_version', index=2,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_details', full_name='CMsgPracticeLobbyCreate.lobby_details', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_game', full_name='CMsgPracticeLobbyCreate.save_game', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPRACTICELOBBYCREATE_SAVEGAME, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2920,
  serialized_end=3194,
)


_CMSGPRACTICELOBBYSETTEAMSLOT = _descriptor.Descriptor(
  name='CMsgPracticeLobbySetTeamSlot',
  full_name='CMsgPracticeLobbySetTeamSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgPracticeLobbySetTeamSlot.team', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot', full_name='CMsgPracticeLobbySetTeamSlot.slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty', full_name='CMsgPracticeLobbySetTeamSlot.bot_difficulty', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3197,
  serialized_end=3362,
)


_CMSGPRACTICELOBBYSETCOACH = _descriptor.Descriptor(
  name='CMsgPracticeLobbySetCoach',
  full_name='CMsgPracticeLobbySetCoach',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgPracticeLobbySetCoach.team', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3364,
  serialized_end=3444,
)


_CMSGPRACTICELOBBYJOINBROADCASTCHANNEL = _descriptor.Descriptor(
  name='CMsgPracticeLobbyJoinBroadcastChannel',
  full_name='CMsgPracticeLobbyJoinBroadcastChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='CMsgPracticeLobbyJoinBroadcastChannel.channel', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preferred_description', full_name='CMsgPracticeLobbyJoinBroadcastChannel.preferred_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preferred_country_code', full_name='CMsgPracticeLobbyJoinBroadcastChannel.preferred_country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preferred_language_code', full_name='CMsgPracticeLobbyJoinBroadcastChannel.preferred_language_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3447,
  serialized_end=3599,
)


_CMSGPRACTICELOBBYCLOSEBROADCASTCHANNEL = _descriptor.Descriptor(
  name='CMsgPracticeLobbyCloseBroadcastChannel',
  full_name='CMsgPracticeLobbyCloseBroadcastChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='CMsgPracticeLobbyCloseBroadcastChannel.channel', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3601,
  serialized_end=3658,
)


_CMSGPRACTICELOBBYTOGGLEBROADCASTCHANNELCAMERAMANSTATUS = _descriptor.Descriptor(
  name='CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus',
  full_name='CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3660,
  serialized_end=3716,
)


_CMSGPRACTICELOBBYKICK = _descriptor.Descriptor(
  name='CMsgPracticeLobbyKick',
  full_name='CMsgPracticeLobbyKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPracticeLobbyKick.account_id', index=0,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3718,
  serialized_end=3761,
)


_CMSGPRACTICELOBBYKICKFROMTEAM = _descriptor.Descriptor(
  name='CMsgPracticeLobbyKickFromTeam',
  full_name='CMsgPracticeLobbyKickFromTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPracticeLobbyKickFromTeam.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3763,
  serialized_end=3814,
)


_CMSGPRACTICELOBBYLEAVE = _descriptor.Descriptor(
  name='CMsgPracticeLobbyLeave',
  full_name='CMsgPracticeLobbyLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3816,
  serialized_end=3840,
)


_CMSGPRACTICELOBBYLAUNCH = _descriptor.Descriptor(
  name='CMsgPracticeLobbyLaunch',
  full_name='CMsgPracticeLobbyLaunch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPracticeLobbyLaunch.client_version', index=0,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3842,
  serialized_end=3891,
)


_CMSGAPPLYTEAMTOPRACTICELOBBY = _descriptor.Descriptor(
  name='CMsgApplyTeamToPracticeLobby',
  full_name='CMsgApplyTeamToPracticeLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgApplyTeamToPracticeLobby.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3893,
  serialized_end=3940,
)


_CMSGCLEARPRACTICELOBBYTEAM = _descriptor.Descriptor(
  name='CMsgClearPracticeLobbyTeam',
  full_name='CMsgClearPracticeLobbyTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3942,
  serialized_end=3970,
)


_CMSGPRACTICELOBBYLIST = _descriptor.Descriptor(
  name='CMsgPracticeLobbyList',
  full_name='CMsgPracticeLobbyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_games', full_name='CMsgPracticeLobbyList.tournament_games', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CMsgPracticeLobbyList.pass_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='CMsgPracticeLobbyList.region', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgPracticeLobbyList.game_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3973,
  serialized_end=4111,
)


_CMSGPRACTICELOBBYLISTRESPONSEENTRY_CLOBBYMEMBER = _descriptor.Descriptor(
  name='CLobbyMember',
  full_name='CMsgPracticeLobbyListResponseEntry.CLobbyMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPracticeLobbyListResponseEntry.CLobbyMember.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgPracticeLobbyListResponseEntry.CLobbyMember.player_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4649,
  serialized_end=4704,
)

_CMSGPRACTICELOBBYLISTRESPONSEENTRY = _descriptor.Descriptor(
  name='CMsgPracticeLobbyListResponseEntry',
  full_name='CMsgPracticeLobbyListResponseEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgPracticeLobbyListResponseEntry.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgPracticeLobbyListResponseEntry.tournament_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_game_id', full_name='CMsgPracticeLobbyListResponseEntry.tournament_game_id', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgPracticeLobbyListResponseEntry.members', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_pass_key', full_name='CMsgPracticeLobbyListResponseEntry.requires_pass_key', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader_account_id', full_name='CMsgPracticeLobbyListResponseEntry.leader_account_id', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgPracticeLobbyListResponseEntry.guild_id', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_logo', full_name='CMsgPracticeLobbyListResponseEntry.guild_logo', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgPracticeLobbyListResponseEntry.name', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_mode', full_name='CMsgPracticeLobbyListResponseEntry.custom_game_mode', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgPracticeLobbyListResponseEntry.game_mode', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friend_present', full_name='CMsgPracticeLobbyListResponseEntry.friend_present', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgPracticeLobbyListResponseEntry.players', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_map_name', full_name='CMsgPracticeLobbyListResponseEntry.custom_map_name', index=13,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_player_count', full_name='CMsgPracticeLobbyListResponseEntry.max_player_count', index=14,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgPracticeLobbyListResponseEntry.server_region', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan_host_ping_to_server_region', full_name='CMsgPracticeLobbyListResponseEntry.lan_host_ping_to_server_region', index=16,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgPracticeLobbyListResponseEntry.league_id', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPRACTICELOBBYLISTRESPONSEENTRY_CLOBBYMEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4114,
  serialized_end=4704,
)


_CMSGPRACTICELOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgPracticeLobbyListResponse',
  full_name='CMsgPracticeLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_games', full_name='CMsgPracticeLobbyListResponse.tournament_games', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgPracticeLobbyListResponse.lobbies', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4706,
  serialized_end=4817,
)


_CMSGLOBBYLIST = _descriptor.Descriptor(
  name='CMsgLobbyList',
  full_name='CMsgLobbyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgLobbyList.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgLobbyList.game_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4819,
  serialized_end=4915,
)


_CMSGLOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgLobbyListResponse',
  full_name='CMsgLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgLobbyListResponse.lobbies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4917,
  serialized_end=4994,
)


_CMSGPRACTICELOBBYJOIN = _descriptor.Descriptor(
  name='CMsgPracticeLobbyJoin',
  full_name='CMsgPracticeLobbyJoin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgPracticeLobbyJoin.lobby_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPracticeLobbyJoin.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CMsgPracticeLobbyJoin.pass_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='CMsgPracticeLobbyJoin.custom_game_crc', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='CMsgPracticeLobbyJoin.custom_game_timestamp', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4997,
  serialized_end=5136,
)


_CMSGPRACTICELOBBYJOINRESPONSE = _descriptor.Descriptor(
  name='CMsgPracticeLobbyJoinResponse',
  full_name='CMsgPracticeLobbyJoinResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgPracticeLobbyJoinResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5138,
  serialized_end=5233,
)


_CMSGFRIENDPRACTICELOBBYLISTREQUEST = _descriptor.Descriptor(
  name='CMsgFriendPracticeLobbyListRequest',
  full_name='CMsgFriendPracticeLobbyListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='friends', full_name='CMsgFriendPracticeLobbyListRequest.friends', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5235,
  serialized_end=5288,
)


_CMSGFRIENDPRACTICELOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgFriendPracticeLobbyListResponse',
  full_name='CMsgFriendPracticeLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgFriendPracticeLobbyListResponse.lobbies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5290,
  serialized_end=5381,
)


_CMSGGUILDMATEPRACTICELOBBYLISTREQUEST = _descriptor.Descriptor(
  name='CMsgGuildmatePracticeLobbyListRequest',
  full_name='CMsgGuildmatePracticeLobbyListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guilds', full_name='CMsgGuildmatePracticeLobbyListRequest.guilds', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5383,
  serialized_end=5438,
)


_CMSGGUILDMATEPRACTICELOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgGuildmatePracticeLobbyListResponse',
  full_name='CMsgGuildmatePracticeLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgGuildmatePracticeLobbyListResponse.lobbies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5440,
  serialized_end=5534,
)


_CMSGJOINABLECUSTOMGAMEMODESREQUEST = _descriptor.Descriptor(
  name='CMsgJoinableCustomGameModesRequest',
  full_name='CMsgJoinableCustomGameModesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgJoinableCustomGameModesRequest.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5536,
  serialized_end=5595,
)


_CMSGJOINABLECUSTOMGAMEMODESRESPONSEENTRY = _descriptor.Descriptor(
  name='CMsgJoinableCustomGameModesResponseEntry',
  full_name='CMsgJoinableCustomGameModesResponseEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgJoinableCustomGameModesResponseEntry.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_count', full_name='CMsgJoinableCustomGameModesResponseEntry.lobby_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_count', full_name='CMsgJoinableCustomGameModesResponseEntry.player_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5597,
  serialized_end=5706,
)


_CMSGJOINABLECUSTOMGAMEMODESRESPONSE = _descriptor.Descriptor(
  name='CMsgJoinableCustomGameModesResponse',
  full_name='CMsgJoinableCustomGameModesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_modes', full_name='CMsgJoinableCustomGameModesResponse.game_modes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5708,
  serialized_end=5808,
)


_CMSGJOINABLECUSTOMLOBBIESREQUEST = _descriptor.Descriptor(
  name='CMsgJoinableCustomLobbiesRequest',
  full_name='CMsgJoinableCustomLobbiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgJoinableCustomLobbiesRequest.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgJoinableCustomLobbiesRequest.custom_game_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5810,
  serialized_end=5891,
)


_CMSGJOINABLECUSTOMLOBBIESRESPONSEENTRY = _descriptor.Descriptor(
  name='CMsgJoinableCustomLobbiesResponseEntry',
  full_name='CMsgJoinableCustomLobbiesResponseEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgJoinableCustomLobbiesResponseEntry.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgJoinableCustomLobbiesResponseEntry.custom_game_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_name', full_name='CMsgJoinableCustomLobbiesResponseEntry.lobby_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgJoinableCustomLobbiesResponseEntry.member_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader_account_id', full_name='CMsgJoinableCustomLobbiesResponseEntry.leader_account_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader_name', full_name='CMsgJoinableCustomLobbiesResponseEntry.leader_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_map_name', full_name='CMsgJoinableCustomLobbiesResponseEntry.custom_map_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_player_count', full_name='CMsgJoinableCustomLobbiesResponseEntry.max_player_count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgJoinableCustomLobbiesResponseEntry.server_region', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan_host_ping_to_server_region', full_name='CMsgJoinableCustomLobbiesResponseEntry.lan_host_ping_to_server_region', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_pass_key', full_name='CMsgJoinableCustomLobbiesResponseEntry.has_pass_key', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5894,
  serialized_end=6202,
)


_CMSGJOINABLECUSTOMLOBBIESRESPONSE = _descriptor.Descriptor(
  name='CMsgJoinableCustomLobbiesResponse',
  full_name='CMsgJoinableCustomLobbiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgJoinableCustomLobbiesResponse.lobbies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6204,
  serialized_end=6297,
)


_CMSGQUICKJOINCUSTOMLOBBY_LEGACYREGIONPING = _descriptor.Descriptor(
  name='LegacyRegionPing',
  full_name='CMsgQuickJoinCustomLobby.LegacyRegionPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgQuickJoinCustomLobby.LegacyRegionPing.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='CMsgQuickJoinCustomLobby.LegacyRegionPing.ping', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_code', full_name='CMsgQuickJoinCustomLobby.LegacyRegionPing.region_code', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6602,
  serialized_end=6678,
)

_CMSGQUICKJOINCUSTOMLOBBY = _descriptor.Descriptor(
  name='CMsgQuickJoinCustomLobby',
  full_name='CMsgQuickJoinCustomLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_server_region', full_name='CMsgQuickJoinCustomLobby.legacy_server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgQuickJoinCustomLobby.custom_game_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgQuickJoinCustomLobby.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_lobby_details', full_name='CMsgQuickJoinCustomLobby.create_lobby_details', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_any_map', full_name='CMsgQuickJoinCustomLobby.allow_any_map', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='legacy_region_pings', full_name='CMsgQuickJoinCustomLobby.legacy_region_pings', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='CMsgQuickJoinCustomLobby.ping_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGQUICKJOINCUSTOMLOBBY_LEGACYREGIONPING, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6300,
  serialized_end=6678,
)


_CMSGQUICKJOINCUSTOMLOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgQuickJoinCustomLobbyResponse',
  full_name='CMsgQuickJoinCustomLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgQuickJoinCustomLobbyResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6680,
  serialized_end=6778,
)


_CMSGBOTGAMECREATE = _descriptor.Descriptor(
  name='CMsgBotGameCreate',
  full_name='CMsgBotGameCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgBotGameCreate.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgBotGameCreate.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty_radiant', full_name='CMsgBotGameCreate.difficulty_radiant', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgBotGameCreate.team', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgBotGameCreate.game_mode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty_dire', full_name='CMsgBotGameCreate.difficulty_dire', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6781,
  serialized_end=7057,
)


_CMSGCUSTOMGAMECREATE = _descriptor.Descriptor(
  name='CMsgCustomGameCreate',
  full_name='CMsgCustomGameCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgCustomGameCreate.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgCustomGameCreate.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty', full_name='CMsgCustomGameCreate.difficulty', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgCustomGameCreate.game_mode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgCustomGameCreate.map', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgCustomGameCreate.custom_game_id', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7060,
  serialized_end=7202,
)


_CMSGEVENTGAMECREATE = _descriptor.Descriptor(
  name='CMsgEventGameCreate',
  full_name='CMsgEventGameCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgEventGameCreate.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgEventGameCreate.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty', full_name='CMsgEventGameCreate.difficulty', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgEventGameCreate.game_mode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgEventGameCreate.map', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgEventGameCreate.custom_game_id', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7205,
  serialized_end=7346,
)


_CMSGDOTAPARTYMEMBERSETCOACH = _descriptor.Descriptor(
  name='CMsgDOTAPartyMemberSetCoach',
  full_name='CMsgDOTAPartyMemberSetCoach',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wants_coach', full_name='CMsgDOTAPartyMemberSetCoach.wants_coach', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7348,
  serialized_end=7398,
)


_CMSGDOTASETGROUPLEADER = _descriptor.Descriptor(
  name='CMsgDOTASetGroupLeader',
  full_name='CMsgDOTASetGroupLeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_leader_steamid', full_name='CMsgDOTASetGroupLeader.new_leader_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7400,
  serialized_end=7452,
)


_CMSGDOTACANCELGROUPINVITES = _descriptor.Descriptor(
  name='CMsgDOTACancelGroupInvites',
  full_name='CMsgDOTACancelGroupInvites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invited_steamids', full_name='CMsgDOTACancelGroupInvites.invited_steamids', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invited_groupids', full_name='CMsgDOTACancelGroupInvites.invited_groupids', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7454,
  serialized_end=7534,
)


_CMSGDOTASETGROUPOPENSTATUS = _descriptor.Descriptor(
  name='CMsgDOTASetGroupOpenStatus',
  full_name='CMsgDOTASetGroupOpenStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='open', full_name='CMsgDOTASetGroupOpenStatus.open', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7536,
  serialized_end=7578,
)


_CMSGDOTAGROUPMERGEINVITE = _descriptor.Descriptor(
  name='CMsgDOTAGroupMergeInvite',
  full_name='CMsgDOTAGroupMergeInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='other_group_id', full_name='CMsgDOTAGroupMergeInvite.other_group_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7580,
  serialized_end=7630,
)


_CMSGDOTAGROUPMERGERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGroupMergeResponse',
  full_name='CMsgDOTAGroupMergeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initiator_group_id', full_name='CMsgDOTAGroupMergeResponse.initiator_group_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CMsgDOTAGroupMergeResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7632,
  serialized_end=7704,
)


_CMSGDOTAGROUPMERGEREPLY = _descriptor.Descriptor(
  name='CMsgDOTAGroupMergeReply',
  full_name='CMsgDOTAGroupMergeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGroupMergeReply.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7706,
  serialized_end=7799,
)


_CMSGSPECTATORLOBBYGAMEDETAILS_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CMsgSpectatorLobbyGameDetails.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgSpectatorLobbyGameDetails.Team.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgSpectatorLobbyGameDetails.Team.team_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgSpectatorLobbyGameDetails.Team.team_logo', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8113,
  serialized_end=8174,
)

_CMSGSPECTATORLOBBYGAMEDETAILS = _descriptor.Descriptor(
  name='CMsgSpectatorLobbyGameDetails',
  full_name='CMsgSpectatorLobbyGameDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgSpectatorLobbyGameDetails.language', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgSpectatorLobbyGameDetails.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CMsgSpectatorLobbyGameDetails.server_steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stream_url', full_name='CMsgSpectatorLobbyGameDetails.stream_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='CMsgSpectatorLobbyGameDetails.stream_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgSpectatorLobbyGameDetails.league_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgSpectatorLobbyGameDetails.series_type', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_game', full_name='CMsgSpectatorLobbyGameDetails.series_game', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team', full_name='CMsgSpectatorLobbyGameDetails.radiant_team', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team', full_name='CMsgSpectatorLobbyGameDetails.dire_team', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSPECTATORLOBBYGAMEDETAILS_TEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7802,
  serialized_end=8174,
)


_CMSGSETSPECTATORLOBBYDETAILS = _descriptor.Descriptor(
  name='CMsgSetSpectatorLobbyDetails',
  full_name='CMsgSetSpectatorLobbyDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgSetSpectatorLobbyDetails.lobby_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_name', full_name='CMsgSetSpectatorLobbyDetails.lobby_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CMsgSetSpectatorLobbyDetails.pass_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_details', full_name='CMsgSetSpectatorLobbyDetails.game_details', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8177,
  serialized_end=8317,
)


_CMSGCREATESPECTATORLOBBY = _descriptor.Descriptor(
  name='CMsgCreateSpectatorLobby',
  full_name='CMsgCreateSpectatorLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgCreateSpectatorLobby.client_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='CMsgCreateSpectatorLobby.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8319,
  serialized_end=8417,
)


_CMSGSPECTATORLOBBYLIST = _descriptor.Descriptor(
  name='CMsgSpectatorLobbyList',
  full_name='CMsgSpectatorLobbyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8419,
  serialized_end=8443,
)


_CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY = _descriptor.Descriptor(
  name='SpectatorLobby',
  full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.lobby_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.game_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_pass_key', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.requires_pass_key', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader_account_id', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.leader_account_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.member_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_details', full_name='CMsgSpectatorLobbyListResponse.SpectatorLobby.game_details', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8546,
  serialized_end=8729,
)

_CMSGSPECTATORLOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgSpectatorLobbyListResponse',
  full_name='CMsgSpectatorLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgSpectatorLobbyListResponse.lobbies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8446,
  serialized_end=8729,
)


_CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKET = _descriptor.Descriptor(
  name='CMsgClientToGCRequestSteamDatagramTicket',
  full_name='CMsgClientToGCRequestSteamDatagramTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CMsgClientToGCRequestSteamDatagramTicket.server_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8731,
  serialized_end=8798,
)


_CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKETRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestSteamDatagramTicketResponse',
  full_name='CMsgClientToGCRequestSteamDatagramTicketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialized_ticket', full_name='CMsgClientToGCRequestSteamDatagramTicketResponse.serialized_ticket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgClientToGCRequestSteamDatagramTicketResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8800,
  serialized_end=8894,
)

_CMSGSTARTFINDINGMATCH.fields_by_name['bot_difficulty'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGSTARTFINDINGMATCH.fields_by_name['match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CMSGSTARTFINDINGMATCH.fields_by_name['game_language_enum'].enum_type = dota__shared__enums__pb2._MATCHLANGUAGES
_CMSGSTARTFINDINGMATCH.fields_by_name['ping_data'].message_type = base__gcmessages__pb2._CMSGCLIENTPINGDATA
_CMSGSTARTFINDINGMATCHRESULT.fields_by_name['result'].enum_type = _ESTARTFINDINGMATCHRESULT
_CMSGPARTYBUILDEROPTIONS.fields_by_name['match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CMSGPARTYBUILDEROPTIONS.fields_by_name['language'].enum_type = dota__shared__enums__pb2._MATCHLANGUAGES
_CMSGREADYUP.fields_by_name['state'].enum_type = dota__shared__enums__pb2._DOTALOBBYREADYSTATE
_CMSGREADYUP.fields_by_name['hardware_specs'].message_type = dota__shared__enums__pb2._CDOTACLIENTHARDWARESPECS
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['team_details'].message_type = dota__gcmessages__common__match__management__pb2._CLOBBYTEAMDETAILS
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['cm_pick'].enum_type = dota__shared__enums__pb2._DOTA_CM_PICK
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['bot_difficulty_radiant'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['game_version'].enum_type = dota__shared__enums__pb2._DOTAGAMEVERSION
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['dota_tv_delay'].enum_type = dota__gcmessages__common__match__management__pb2._LOBBYDOTATVDELAY
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['visibility'].enum_type = dota__shared__enums__pb2._DOTALOBBYVISIBILITY
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['league_selection_priority_choice'].enum_type = dota__shared__enums__pb2._SELECTIONPRIORITYTYPE
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['league_non_selection_priority_choice'].enum_type = dota__shared__enums__pb2._SELECTIONPRIORITYTYPE
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['pause_setting'].enum_type = dota__gcmessages__common__match__management__pb2._LOBBYDOTAPAUSESETTING
_CMSGPRACTICELOBBYSETDETAILS.fields_by_name['bot_difficulty_dire'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGPRACTICELOBBYCREATE_SAVEGAME.containing_type = _CMSGPRACTICELOBBYCREATE
_CMSGPRACTICELOBBYCREATE.fields_by_name['lobby_details'].message_type = _CMSGPRACTICELOBBYSETDETAILS
_CMSGPRACTICELOBBYCREATE.fields_by_name['save_game'].message_type = _CMSGPRACTICELOBBYCREATE_SAVEGAME
_CMSGPRACTICELOBBYSETTEAMSLOT.fields_by_name['team'].enum_type = dota__shared__enums__pb2._DOTA_GC_TEAM
_CMSGPRACTICELOBBYSETTEAMSLOT.fields_by_name['bot_difficulty'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGPRACTICELOBBYSETCOACH.fields_by_name['team'].enum_type = dota__shared__enums__pb2._DOTA_GC_TEAM
_CMSGPRACTICELOBBYLIST.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGPRACTICELOBBYLISTRESPONSEENTRY_CLOBBYMEMBER.containing_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
_CMSGPRACTICELOBBYLISTRESPONSEENTRY.fields_by_name['members'].message_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY_CLOBBYMEMBER
_CMSGPRACTICELOBBYLISTRESPONSEENTRY.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGPRACTICELOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
_CMSGLOBBYLIST.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGLOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
_CMSGPRACTICELOBBYJOINRESPONSE.fields_by_name['result'].enum_type = dota__shared__enums__pb2._DOTAJOINLOBBYRESULT
_CMSGFRIENDPRACTICELOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
_CMSGGUILDMATEPRACTICELOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
_CMSGJOINABLECUSTOMGAMEMODESRESPONSE.fields_by_name['game_modes'].message_type = _CMSGJOINABLECUSTOMGAMEMODESRESPONSEENTRY
_CMSGJOINABLECUSTOMLOBBIESRESPONSE.fields_by_name['lobbies'].message_type = _CMSGJOINABLECUSTOMLOBBIESRESPONSEENTRY
_CMSGQUICKJOINCUSTOMLOBBY_LEGACYREGIONPING.containing_type = _CMSGQUICKJOINCUSTOMLOBBY
_CMSGQUICKJOINCUSTOMLOBBY.fields_by_name['create_lobby_details'].message_type = _CMSGPRACTICELOBBYSETDETAILS
_CMSGQUICKJOINCUSTOMLOBBY.fields_by_name['legacy_region_pings'].message_type = _CMSGQUICKJOINCUSTOMLOBBY_LEGACYREGIONPING
_CMSGQUICKJOINCUSTOMLOBBY.fields_by_name['ping_data'].message_type = base__gcmessages__pb2._CMSGCLIENTPINGDATA
_CMSGQUICKJOINCUSTOMLOBBYRESPONSE.fields_by_name['result'].enum_type = dota__shared__enums__pb2._DOTAJOINLOBBYRESULT
_CMSGBOTGAMECREATE.fields_by_name['difficulty_radiant'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGBOTGAMECREATE.fields_by_name['team'].enum_type = dota__shared__enums__pb2._DOTA_GC_TEAM
_CMSGBOTGAMECREATE.fields_by_name['difficulty_dire'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CMSGDOTAGROUPMERGEREPLY.fields_by_name['result'].enum_type = dota__client__enums__pb2._EDOTAGROUPMERGERESULT
_CMSGSPECTATORLOBBYGAMEDETAILS_TEAM.containing_type = _CMSGSPECTATORLOBBYGAMEDETAILS
_CMSGSPECTATORLOBBYGAMEDETAILS.fields_by_name['radiant_team'].message_type = _CMSGSPECTATORLOBBYGAMEDETAILS_TEAM
_CMSGSPECTATORLOBBYGAMEDETAILS.fields_by_name['dire_team'].message_type = _CMSGSPECTATORLOBBYGAMEDETAILS_TEAM
_CMSGSETSPECTATORLOBBYDETAILS.fields_by_name['game_details'].message_type = _CMSGSPECTATORLOBBYGAMEDETAILS
_CMSGCREATESPECTATORLOBBY.fields_by_name['details'].message_type = _CMSGSETSPECTATORLOBBYDETAILS
_CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY.fields_by_name['game_details'].message_type = _CMSGSPECTATORLOBBYGAMEDETAILS
_CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY.containing_type = _CMSGSPECTATORLOBBYLISTRESPONSE
_CMSGSPECTATORLOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY
DESCRIPTOR.message_types_by_name['CMsgStartFindingMatch'] = _CMSGSTARTFINDINGMATCH
DESCRIPTOR.message_types_by_name['CMsgStartFindingMatchResult'] = _CMSGSTARTFINDINGMATCHRESULT
DESCRIPTOR.message_types_by_name['CMsgStopFindingMatch'] = _CMSGSTOPFINDINGMATCH
DESCRIPTOR.message_types_by_name['CMsgPartyBuilderOptions'] = _CMSGPARTYBUILDEROPTIONS
DESCRIPTOR.message_types_by_name['CMsgReadyUp'] = _CMSGREADYUP
DESCRIPTOR.message_types_by_name['CMsgReadyUpStatus'] = _CMSGREADYUPSTATUS
DESCRIPTOR.message_types_by_name['CMsgAbandonCurrentGame'] = _CMSGABANDONCURRENTGAME
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbySetDetails'] = _CMSGPRACTICELOBBYSETDETAILS
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyCreate'] = _CMSGPRACTICELOBBYCREATE
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbySetTeamSlot'] = _CMSGPRACTICELOBBYSETTEAMSLOT
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbySetCoach'] = _CMSGPRACTICELOBBYSETCOACH
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyJoinBroadcastChannel'] = _CMSGPRACTICELOBBYJOINBROADCASTCHANNEL
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyCloseBroadcastChannel'] = _CMSGPRACTICELOBBYCLOSEBROADCASTCHANNEL
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus'] = _CMSGPRACTICELOBBYTOGGLEBROADCASTCHANNELCAMERAMANSTATUS
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyKick'] = _CMSGPRACTICELOBBYKICK
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyKickFromTeam'] = _CMSGPRACTICELOBBYKICKFROMTEAM
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyLeave'] = _CMSGPRACTICELOBBYLEAVE
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyLaunch'] = _CMSGPRACTICELOBBYLAUNCH
DESCRIPTOR.message_types_by_name['CMsgApplyTeamToPracticeLobby'] = _CMSGAPPLYTEAMTOPRACTICELOBBY
DESCRIPTOR.message_types_by_name['CMsgClearPracticeLobbyTeam'] = _CMSGCLEARPRACTICELOBBYTEAM
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyList'] = _CMSGPRACTICELOBBYLIST
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyListResponseEntry'] = _CMSGPRACTICELOBBYLISTRESPONSEENTRY
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyListResponse'] = _CMSGPRACTICELOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgLobbyList'] = _CMSGLOBBYLIST
DESCRIPTOR.message_types_by_name['CMsgLobbyListResponse'] = _CMSGLOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyJoin'] = _CMSGPRACTICELOBBYJOIN
DESCRIPTOR.message_types_by_name['CMsgPracticeLobbyJoinResponse'] = _CMSGPRACTICELOBBYJOINRESPONSE
DESCRIPTOR.message_types_by_name['CMsgFriendPracticeLobbyListRequest'] = _CMSGFRIENDPRACTICELOBBYLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgFriendPracticeLobbyListResponse'] = _CMSGFRIENDPRACTICELOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGuildmatePracticeLobbyListRequest'] = _CMSGGUILDMATEPRACTICELOBBYLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGuildmatePracticeLobbyListResponse'] = _CMSGGUILDMATEPRACTICELOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomGameModesRequest'] = _CMSGJOINABLECUSTOMGAMEMODESREQUEST
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomGameModesResponseEntry'] = _CMSGJOINABLECUSTOMGAMEMODESRESPONSEENTRY
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomGameModesResponse'] = _CMSGJOINABLECUSTOMGAMEMODESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomLobbiesRequest'] = _CMSGJOINABLECUSTOMLOBBIESREQUEST
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomLobbiesResponseEntry'] = _CMSGJOINABLECUSTOMLOBBIESRESPONSEENTRY
DESCRIPTOR.message_types_by_name['CMsgJoinableCustomLobbiesResponse'] = _CMSGJOINABLECUSTOMLOBBIESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgQuickJoinCustomLobby'] = _CMSGQUICKJOINCUSTOMLOBBY
DESCRIPTOR.message_types_by_name['CMsgQuickJoinCustomLobbyResponse'] = _CMSGQUICKJOINCUSTOMLOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgBotGameCreate'] = _CMSGBOTGAMECREATE
DESCRIPTOR.message_types_by_name['CMsgCustomGameCreate'] = _CMSGCUSTOMGAMECREATE
DESCRIPTOR.message_types_by_name['CMsgEventGameCreate'] = _CMSGEVENTGAMECREATE
DESCRIPTOR.message_types_by_name['CMsgDOTAPartyMemberSetCoach'] = _CMSGDOTAPARTYMEMBERSETCOACH
DESCRIPTOR.message_types_by_name['CMsgDOTASetGroupLeader'] = _CMSGDOTASETGROUPLEADER
DESCRIPTOR.message_types_by_name['CMsgDOTACancelGroupInvites'] = _CMSGDOTACANCELGROUPINVITES
DESCRIPTOR.message_types_by_name['CMsgDOTASetGroupOpenStatus'] = _CMSGDOTASETGROUPOPENSTATUS
DESCRIPTOR.message_types_by_name['CMsgDOTAGroupMergeInvite'] = _CMSGDOTAGROUPMERGEINVITE
DESCRIPTOR.message_types_by_name['CMsgDOTAGroupMergeResponse'] = _CMSGDOTAGROUPMERGERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGroupMergeReply'] = _CMSGDOTAGROUPMERGEREPLY
DESCRIPTOR.message_types_by_name['CMsgSpectatorLobbyGameDetails'] = _CMSGSPECTATORLOBBYGAMEDETAILS
DESCRIPTOR.message_types_by_name['CMsgSetSpectatorLobbyDetails'] = _CMSGSETSPECTATORLOBBYDETAILS
DESCRIPTOR.message_types_by_name['CMsgCreateSpectatorLobby'] = _CMSGCREATESPECTATORLOBBY
DESCRIPTOR.message_types_by_name['CMsgSpectatorLobbyList'] = _CMSGSPECTATORLOBBYLIST
DESCRIPTOR.message_types_by_name['CMsgSpectatorLobbyListResponse'] = _CMSGSPECTATORLOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestSteamDatagramTicket'] = _CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKET
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestSteamDatagramTicketResponse'] = _CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKETRESPONSE
DESCRIPTOR.enum_types_by_name['EStartFindingMatchResult'] = _ESTARTFINDINGMATCHRESULT

CMsgStartFindingMatch = _reflection.GeneratedProtocolMessageType('CMsgStartFindingMatch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTARTFINDINGMATCH,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStartFindingMatch)
  ))
_sym_db.RegisterMessage(CMsgStartFindingMatch)

CMsgStartFindingMatchResult = _reflection.GeneratedProtocolMessageType('CMsgStartFindingMatchResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTARTFINDINGMATCHRESULT,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStartFindingMatchResult)
  ))
_sym_db.RegisterMessage(CMsgStartFindingMatchResult)

CMsgStopFindingMatch = _reflection.GeneratedProtocolMessageType('CMsgStopFindingMatch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTOPFINDINGMATCH,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStopFindingMatch)
  ))
_sym_db.RegisterMessage(CMsgStopFindingMatch)

CMsgPartyBuilderOptions = _reflection.GeneratedProtocolMessageType('CMsgPartyBuilderOptions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYBUILDEROPTIONS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPartyBuilderOptions)
  ))
_sym_db.RegisterMessage(CMsgPartyBuilderOptions)

CMsgReadyUp = _reflection.GeneratedProtocolMessageType('CMsgReadyUp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREADYUP,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgReadyUp)
  ))
_sym_db.RegisterMessage(CMsgReadyUp)

CMsgReadyUpStatus = _reflection.GeneratedProtocolMessageType('CMsgReadyUpStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREADYUPSTATUS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgReadyUpStatus)
  ))
_sym_db.RegisterMessage(CMsgReadyUpStatus)

CMsgAbandonCurrentGame = _reflection.GeneratedProtocolMessageType('CMsgAbandonCurrentGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGABANDONCURRENTGAME,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAbandonCurrentGame)
  ))
_sym_db.RegisterMessage(CMsgAbandonCurrentGame)

CMsgPracticeLobbySetDetails = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbySetDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYSETDETAILS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbySetDetails)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbySetDetails)

CMsgPracticeLobbyCreate = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyCreate', (_message.Message,), dict(

  SaveGame = _reflection.GeneratedProtocolMessageType('SaveGame', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPRACTICELOBBYCREATE_SAVEGAME,
    __module__ = 'dota_gcmessages_client_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyCreate.SaveGame)
    ))
  ,
  DESCRIPTOR = _CMSGPRACTICELOBBYCREATE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyCreate)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyCreate)
_sym_db.RegisterMessage(CMsgPracticeLobbyCreate.SaveGame)

CMsgPracticeLobbySetTeamSlot = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbySetTeamSlot', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYSETTEAMSLOT,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbySetTeamSlot)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbySetTeamSlot)

CMsgPracticeLobbySetCoach = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbySetCoach', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYSETCOACH,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbySetCoach)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbySetCoach)

CMsgPracticeLobbyJoinBroadcastChannel = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyJoinBroadcastChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYJOINBROADCASTCHANNEL,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyJoinBroadcastChannel)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyJoinBroadcastChannel)

CMsgPracticeLobbyCloseBroadcastChannel = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyCloseBroadcastChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYCLOSEBROADCASTCHANNEL,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyCloseBroadcastChannel)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyCloseBroadcastChannel)

CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYTOGGLEBROADCASTCHANNELCAMERAMANSTATUS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyToggleBroadcastChannelCameramanStatus)

CMsgPracticeLobbyKick = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyKick', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYKICK,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyKick)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyKick)

CMsgPracticeLobbyKickFromTeam = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyKickFromTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYKICKFROMTEAM,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyKickFromTeam)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyKickFromTeam)

CMsgPracticeLobbyLeave = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyLeave', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYLEAVE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyLeave)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyLeave)

CMsgPracticeLobbyLaunch = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyLaunch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYLAUNCH,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyLaunch)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyLaunch)

CMsgApplyTeamToPracticeLobby = _reflection.GeneratedProtocolMessageType('CMsgApplyTeamToPracticeLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYTEAMTOPRACTICELOBBY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyTeamToPracticeLobby)
  ))
_sym_db.RegisterMessage(CMsgApplyTeamToPracticeLobby)

CMsgClearPracticeLobbyTeam = _reflection.GeneratedProtocolMessageType('CMsgClearPracticeLobbyTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLEARPRACTICELOBBYTEAM,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClearPracticeLobbyTeam)
  ))
_sym_db.RegisterMessage(CMsgClearPracticeLobbyTeam)

CMsgPracticeLobbyList = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYLIST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyList)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyList)

CMsgPracticeLobbyListResponseEntry = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyListResponseEntry', (_message.Message,), dict(

  CLobbyMember = _reflection.GeneratedProtocolMessageType('CLobbyMember', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPRACTICELOBBYLISTRESPONSEENTRY_CLOBBYMEMBER,
    __module__ = 'dota_gcmessages_client_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyListResponseEntry.CLobbyMember)
    ))
  ,
  DESCRIPTOR = _CMSGPRACTICELOBBYLISTRESPONSEENTRY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyListResponseEntry)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyListResponseEntry)
_sym_db.RegisterMessage(CMsgPracticeLobbyListResponseEntry.CLobbyMember)

CMsgPracticeLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyListResponse)

CMsgLobbyList = _reflection.GeneratedProtocolMessageType('CMsgLobbyList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOBBYLIST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLobbyList)
  ))
_sym_db.RegisterMessage(CMsgLobbyList)

CMsgLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgLobbyListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOBBYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgLobbyListResponse)

CMsgPracticeLobbyJoin = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyJoin', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYJOIN,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyJoin)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyJoin)

CMsgPracticeLobbyJoinResponse = _reflection.GeneratedProtocolMessageType('CMsgPracticeLobbyJoinResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRACTICELOBBYJOINRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPracticeLobbyJoinResponse)
  ))
_sym_db.RegisterMessage(CMsgPracticeLobbyJoinResponse)

CMsgFriendPracticeLobbyListRequest = _reflection.GeneratedProtocolMessageType('CMsgFriendPracticeLobbyListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFRIENDPRACTICELOBBYLISTREQUEST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFriendPracticeLobbyListRequest)
  ))
_sym_db.RegisterMessage(CMsgFriendPracticeLobbyListRequest)

CMsgFriendPracticeLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgFriendPracticeLobbyListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFRIENDPRACTICELOBBYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFriendPracticeLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgFriendPracticeLobbyListResponse)

CMsgGuildmatePracticeLobbyListRequest = _reflection.GeneratedProtocolMessageType('CMsgGuildmatePracticeLobbyListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGUILDMATEPRACTICELOBBYLISTREQUEST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGuildmatePracticeLobbyListRequest)
  ))
_sym_db.RegisterMessage(CMsgGuildmatePracticeLobbyListRequest)

CMsgGuildmatePracticeLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgGuildmatePracticeLobbyListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGUILDMATEPRACTICELOBBYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGuildmatePracticeLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgGuildmatePracticeLobbyListResponse)

CMsgJoinableCustomGameModesRequest = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomGameModesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMGAMEMODESREQUEST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomGameModesRequest)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomGameModesRequest)

CMsgJoinableCustomGameModesResponseEntry = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomGameModesResponseEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMGAMEMODESRESPONSEENTRY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomGameModesResponseEntry)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomGameModesResponseEntry)

CMsgJoinableCustomGameModesResponse = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomGameModesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMGAMEMODESRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomGameModesResponse)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomGameModesResponse)

CMsgJoinableCustomLobbiesRequest = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomLobbiesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMLOBBIESREQUEST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomLobbiesRequest)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomLobbiesRequest)

CMsgJoinableCustomLobbiesResponseEntry = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomLobbiesResponseEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMLOBBIESRESPONSEENTRY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomLobbiesResponseEntry)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomLobbiesResponseEntry)

CMsgJoinableCustomLobbiesResponse = _reflection.GeneratedProtocolMessageType('CMsgJoinableCustomLobbiesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGJOINABLECUSTOMLOBBIESRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgJoinableCustomLobbiesResponse)
  ))
_sym_db.RegisterMessage(CMsgJoinableCustomLobbiesResponse)

CMsgQuickJoinCustomLobby = _reflection.GeneratedProtocolMessageType('CMsgQuickJoinCustomLobby', (_message.Message,), dict(

  LegacyRegionPing = _reflection.GeneratedProtocolMessageType('LegacyRegionPing', (_message.Message,), dict(
    DESCRIPTOR = _CMSGQUICKJOINCUSTOMLOBBY_LEGACYREGIONPING,
    __module__ = 'dota_gcmessages_client_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CMsgQuickJoinCustomLobby.LegacyRegionPing)
    ))
  ,
  DESCRIPTOR = _CMSGQUICKJOINCUSTOMLOBBY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgQuickJoinCustomLobby)
  ))
_sym_db.RegisterMessage(CMsgQuickJoinCustomLobby)
_sym_db.RegisterMessage(CMsgQuickJoinCustomLobby.LegacyRegionPing)

CMsgQuickJoinCustomLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgQuickJoinCustomLobbyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGQUICKJOINCUSTOMLOBBYRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgQuickJoinCustomLobbyResponse)
  ))
_sym_db.RegisterMessage(CMsgQuickJoinCustomLobbyResponse)

CMsgBotGameCreate = _reflection.GeneratedProtocolMessageType('CMsgBotGameCreate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGBOTGAMECREATE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgBotGameCreate)
  ))
_sym_db.RegisterMessage(CMsgBotGameCreate)

CMsgCustomGameCreate = _reflection.GeneratedProtocolMessageType('CMsgCustomGameCreate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCUSTOMGAMECREATE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCustomGameCreate)
  ))
_sym_db.RegisterMessage(CMsgCustomGameCreate)

CMsgEventGameCreate = _reflection.GeneratedProtocolMessageType('CMsgEventGameCreate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEVENTGAMECREATE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgEventGameCreate)
  ))
_sym_db.RegisterMessage(CMsgEventGameCreate)

CMsgDOTAPartyMemberSetCoach = _reflection.GeneratedProtocolMessageType('CMsgDOTAPartyMemberSetCoach', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPARTYMEMBERSETCOACH,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPartyMemberSetCoach)
  ))
_sym_db.RegisterMessage(CMsgDOTAPartyMemberSetCoach)

CMsgDOTASetGroupLeader = _reflection.GeneratedProtocolMessageType('CMsgDOTASetGroupLeader', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETGROUPLEADER,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetGroupLeader)
  ))
_sym_db.RegisterMessage(CMsgDOTASetGroupLeader)

CMsgDOTACancelGroupInvites = _reflection.GeneratedProtocolMessageType('CMsgDOTACancelGroupInvites', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACANCELGROUPINVITES,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACancelGroupInvites)
  ))
_sym_db.RegisterMessage(CMsgDOTACancelGroupInvites)

CMsgDOTASetGroupOpenStatus = _reflection.GeneratedProtocolMessageType('CMsgDOTASetGroupOpenStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETGROUPOPENSTATUS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetGroupOpenStatus)
  ))
_sym_db.RegisterMessage(CMsgDOTASetGroupOpenStatus)

CMsgDOTAGroupMergeInvite = _reflection.GeneratedProtocolMessageType('CMsgDOTAGroupMergeInvite', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGROUPMERGEINVITE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGroupMergeInvite)
  ))
_sym_db.RegisterMessage(CMsgDOTAGroupMergeInvite)

CMsgDOTAGroupMergeResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGroupMergeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGROUPMERGERESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGroupMergeResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGroupMergeResponse)

CMsgDOTAGroupMergeReply = _reflection.GeneratedProtocolMessageType('CMsgDOTAGroupMergeReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGROUPMERGEREPLY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGroupMergeReply)
  ))
_sym_db.RegisterMessage(CMsgDOTAGroupMergeReply)

CMsgSpectatorLobbyGameDetails = _reflection.GeneratedProtocolMessageType('CMsgSpectatorLobbyGameDetails', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSPECTATORLOBBYGAMEDETAILS_TEAM,
    __module__ = 'dota_gcmessages_client_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSpectatorLobbyGameDetails.Team)
    ))
  ,
  DESCRIPTOR = _CMSGSPECTATORLOBBYGAMEDETAILS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSpectatorLobbyGameDetails)
  ))
_sym_db.RegisterMessage(CMsgSpectatorLobbyGameDetails)
_sym_db.RegisterMessage(CMsgSpectatorLobbyGameDetails.Team)

CMsgSetSpectatorLobbyDetails = _reflection.GeneratedProtocolMessageType('CMsgSetSpectatorLobbyDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETSPECTATORLOBBYDETAILS,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetSpectatorLobbyDetails)
  ))
_sym_db.RegisterMessage(CMsgSetSpectatorLobbyDetails)

CMsgCreateSpectatorLobby = _reflection.GeneratedProtocolMessageType('CMsgCreateSpectatorLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCREATESPECTATORLOBBY,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCreateSpectatorLobby)
  ))
_sym_db.RegisterMessage(CMsgCreateSpectatorLobby)

CMsgSpectatorLobbyList = _reflection.GeneratedProtocolMessageType('CMsgSpectatorLobbyList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSPECTATORLOBBYLIST,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSpectatorLobbyList)
  ))
_sym_db.RegisterMessage(CMsgSpectatorLobbyList)

CMsgSpectatorLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgSpectatorLobbyListResponse', (_message.Message,), dict(

  SpectatorLobby = _reflection.GeneratedProtocolMessageType('SpectatorLobby', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSPECTATORLOBBYLISTRESPONSE_SPECTATORLOBBY,
    __module__ = 'dota_gcmessages_client_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSpectatorLobbyListResponse.SpectatorLobby)
    ))
  ,
  DESCRIPTOR = _CMSGSPECTATORLOBBYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSpectatorLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgSpectatorLobbyListResponse)
_sym_db.RegisterMessage(CMsgSpectatorLobbyListResponse.SpectatorLobby)

CMsgClientToGCRequestSteamDatagramTicket = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestSteamDatagramTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKET,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestSteamDatagramTicket)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestSteamDatagramTicket)

CMsgClientToGCRequestSteamDatagramTicketResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestSteamDatagramTicketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTSTEAMDATAGRAMTICKETRESPONSE,
  __module__ = 'dota_gcmessages_client_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestSteamDatagramTicketResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestSteamDatagramTicketResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CMSGPRACTICELOBBYLISTRESPONSEENTRY.fields_by_name['id'].has_options = True
_CMSGPRACTICELOBBYLISTRESPONSEENTRY.fields_by_name['id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
# @@protoc_insertion_point(module_scope)
